'use strict';

var globals = require('../global')
var refreshToken = 'cm02YmUxcXd4YWd5OWdtOHJ0dTZ2anAycHI0ZzM0ajdqb2Nremx3ZWxmNnF2czN5dWdvNnpwNHEyajB2bHpqdA=='
var nationalservicealliance = require('../nationalservicealliance')
var global = require('./testGlobal.js')
var https = require('https')
var chai = require('chai');
var expect = chai.expect

describe('NSA Module', function () {

    //Tests for response 
    it("Calling Welcome", function (done) {
        var nsa = nationalservicealliance()
        nsa.welcome(function (data, status) {

            expect(data).to.equal('Welcome')
            done()
        })
    });

    //Tests for response 
    it("Calling Login", function (done) {
        var nsa = nationalservicealliance()
        nsa.login(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            global.testCurrentObject.state.token = data.jwt
            global.testCurrentObject.state.refreshToken = data.refreshToken
            done()
        })
    });

    //Tests for response 
    it("Calling Refresh Login", function (done) {
        var nsa = nationalservicealliance()
        nsa.refreshLogin(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling Logout", function (done) {
        var nsa = nationalservicealliance()
        nsa.logout(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling Login Again", function (done) {
        var nsa = nationalservicealliance()
        nsa.login(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            global.testToken = data.jwt
            global.testRefreshToken = data.refreshToken
            done()
        })
    });

    //Tests for response 
    it("Calling List Users", function (done) {
        var nsa = nationalservicealliance()

        nsa.listUsers(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling Update User Need to remove", function (done) {
        var nsa = nationalservicealliance()

        global.testCurrentObject.state.requestData = {
            "firstName": "John",
            "lastName": "Doe",
            "email": "john.doe@test.coma"
        }

        nsa.updateUser(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling Update User Password Need to remove", function (done) {
        var nsa = nationalservicealliance()

        global.testCurrentObject.state.requestData = {
            "oldPassword": "sachannew1",
            "newPassword": "sachannew"
        }

        nsa.updateUserPassword(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling Update User", function (done) {
        var nsa = nationalservicealliance()

        global.testCurrentObject.state.requestData = {
            "firstName": "John",
            "lastName": "Doe",
            "email": "john.doe@test.com"
        }

        nsa.updateUser(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling Update User Password", function (done) {
        var nsa = nationalservicealliance()

        global.testCurrentObject.state.requestData = {
            "oldPassword": "sachannew",
            "newPassword": "sachannew1"
        }

        nsa.updateUserPassword(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling List Availability", function (done) {
        var nsa = nationalservicealliance()

        nsa.listAvailability(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling List Availability With Hash", function (done) {
        var nsa = nationalservicealliance()
        var HashRequestBody = [{ "date": "2016-01-01", "hash": "4740cf1981588a63ba132c38c6592a70" }, { "date": "2016-01-02", "hash": "74bbff39cec3d5d059df7f19a6bbef66" }, { "date": "2016-01-03", "hash": "4ebeb6a3757535e3cfe08e1da2897e0e" }]

        global.testCurrentObject.state.requestData = HashRequestBody

        nsa.listAvailabilityWithHash(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling List Availability Defaults", function (done) {
        var nsa = nationalservicealliance()

        nsa.listAvailabilityDefaults(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling List Availability Defaults", function (done) {
        var nsa = nationalservicealliance()

        nsa.listAvailabilityDefaults(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling Add Availability", function (done) {
        var nsa = nationalservicealliance()

        global.testCurrentObject.state.requestData = [

            {
                "date": "2016-01-01",
                "slots": [
                    "P"
                    , "A"
                    , "E"
                ]
            },
            {
                "date": "2016-01-02",
                "slots": [
                    "E"
                ]
            },
            {
                "date": "2016-01-03",
                "slots": [
                    "D"
                ]
            }
        ]

        nsa.addAvailability(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling Update Availability By Date", function (done) {
        var nsa = nationalservicealliance()

        global.testCurrentObject.state.requestData = {
            "slots": [
                "P"
                , "A"
                , "E"
            ]
        }

        nsa.updateAvailabilityByDate(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });


    //Tests for response 
    it("Calling Remove Availability", function (done) {
        var nsa = nationalservicealliance()

        global.testCurrentObject.state.date = '2016-03-04'

        nsa.removeAvailabilityByDate(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(403)
            done()
        })
    });

    //Tests for response 
    it("Calling Update Availability Defaults", function (done) {
        var nsa = nationalservicealliance()

        global.testCurrentObject.state.requestData = [
            {
                "day": "monday",
                "slots": [
                    "P"
                    , "A"
                    , "E"
                ]
            },
            {
                "day": "wednesday",
                "slots": [
                    "E"
                ]
            },
            {
                "day": "friday",
                "slots": [
                    "P"
                    , "A"
                    , "E"
                ]
            }
        ]

        nsa.updateAvailabilityDefaults(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling Get Dispatches", function (done) {
        var nsa = nationalservicealliance()

        nsa.getDispatches(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling Get Dispatches with Hash", function (done) {
        var nsa = nationalservicealliance()
        var HashRequestBody = [{ "dispatchNumber": "NYC201505232896", "hash": "eeaa5d2481578deaf6097610780c6773" }, { "dispatchNumber": "NYC201505233669", "hash": "b6d4011af919060e4127f00cce484e1c" }, { "dispatchNumber": "NYC20150523363", "hash": "be0b10125326d4545a23713f5b7f7dc9" }]

        global.testCurrentObject.state.requestData = HashRequestBody;

        nsa.getDispatchesWithHash(global.testCurrentObject, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });


    //Tests for response 
    it("Calling GET Dispatches By DispatchNumber", function (done) {
        var nsa = nationalservicealliance()

        nsa.getDispatchesByDispatchNumber('NYC201509256146', function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling Update Dispatches By DisparchNumber", function (done) {
        var nsa = nationalservicealliance()

        nsa.updateDispatchesByDispatchNumber('NYC201509256146', {
            "serial": "serial123",
            "notes": "Replaced part"
        },
            function (data, status) {

                expect(status).to.equal(200)
                done()
            })
    });

    //Tests for response 
    it("Calling Update Dispatches Schedules", function (done) {
        var nsa = nationalservicealliance()

        nsa.updateDispatchesSchedules('NYC201509256146', {
            "newDate": "2016-06-14",
            "timeSlot": "A",
            "reason": 1,
            "notes": "Customer did not answer. Waited for 10 minutes"
        }, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });


    //Tests for response 
    it("Calling Update Dispatches Completions", function (done) {
        var nsa = nationalservicealliance()

        nsa.updateDispatchesCompletions('NYC201509256146', {
            "runDate": "2016-07-07",
            "serialNumber": "06861",
            "statusCode": "CP",
            "servicePerformed": "open the equpment and replace the screen.",
            "notes": "doing good job",
            "repairCode": "PTEL",
            "Action": "closeBill",
            "repairSuccessful": true
        }, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling Get Dispatches Attachments", function (done) {
        var nsa = nationalservicealliance()

        nsa.getDispatchesAttachments('NYC201509256146', function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling Add Dispatches Attachments", function (done) {
        var nsa = nationalservicealliance()

        nsa.addDispatchesAttachments('NYC201509256146', [
            {
                "attachmentTypeID": "1",
                "extension": ".jpg"
            },
            {
                "attachmentTypeID": "2",
                "extension": ".txt"
            }

        ], function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling List Payments", function (done) {
        var nsa = nationalservicealliance()

        nsa.listPayments('?page=2', function (data, status) {

            expect(status).to.equal(200)
            done()
        })

    });

    //Tests for response 
    it("Calling List Payments With Hash", function (done) {
        var nsa = nationalservicealliance()
        var HashRequestBody = '[{"batchNumber":2,"hash":"721644efd06f787c447fcb0495e4e2ee"},{"batchNumber":5,"hash":"47c338440953d3e70df7283439be3f57"},{"batchNumber":3,"hash":"17a9654d678996741f78a43999185690a"}]'

        nsa.listPaymentsWithHash('?page=2', JSON.parse(HashRequestBody), function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling List Payment Batches", function (done) {
        var nsa = nationalservicealliance()

        nsa.listPaymentsByBatchId(2, function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

    //Tests for response 
    it("Calling List Payment Calls", function (done) {
        var nsa = nationalservicealliance()

        nsa.listPaymentsByCallId('NYC201509256146', function (data, status) {

            expect(status).to.equal(200)
            done()
        })
    });

});

